aboutsummaryrefslogtreecommitdiffstats
path: root/lualib
diff options
context:
space:
mode:
Diffstat (limited to 'lualib')
-rw-r--r--lualib/lua_mime.lua6
1 files changed, 5 insertions, 1 deletions
diff --git a/lualib/lua_mime.lua b/lualib/lua_mime.lua
index 4f8450964..575e9152c 100644
--- a/lualib/lua_mime.lua
+++ b/lualib/lua_mime.lua
@@ -596,7 +596,8 @@ exports.message_to_ucl = function(task, stringify_content)
return nil
end
- -- Envelope (smtp) information form email
+
+ -- Envelope (smtp) information from email (nil if empty)
result.envelope = {
from_smtp = (task:get_from('smtp') or E)[1],
recipients_smtp = task:get_recipients('smtp'),
@@ -605,6 +606,9 @@ exports.message_to_ucl = function(task, stringify_content)
client_ip = maybe_stringify_ip(task:get_client_ip()),
from_ip = maybe_stringify_ip(task:get_from_ip()),
}
+ if not next(result.envelope) then
+ result.envelope = nil
+ end
local parts = task:get_parts() or E
result.parts = {}